@@ -2,7 +2,8 @@ import os
 
 from PIL import ImageFont, Image, ImageDraw
 from StreamDeck.ImageHelpers import PILHelper
-from devdeck.image_processing import render_key_image
+from devdeck_core.image_processing import render_key_image
+from devdeck_core.renderer import RendererManager
 
 
 class DeckContext:
@@ -35,12 +36,5 @@ class DeckContext:
     def pop_active_deck(self):
         self.__devdeck.pop_active_deck()
 
-    def render_text(self, key_no, text, font_size=120, fill="white"):
-        font = ImageFont.truetype(os.path.join(os.path.dirname(__file__), "../assets", 'Roboto-Regular.ttf'), font_size)
-
-        image = Image.new("RGB", (512, 512))
-        draw = ImageDraw.Draw(image)
-        label_w, label_h = draw.textsize('%s' % text, font=font)
-        label_pos = ((512 - label_w) // 2, (512 - label_h) // 2)
-        draw.text(label_pos, text=text, font=font, fill=fill)
-        self.set_key_image_native(key_no, image)
+    def renderer(self, key_no):
+        return RendererManager(key_no, self)
